@@ -261,11 +261,11 @@ typedef _Decimal128 D128;
 /* Don't use NON_NUMERIC_CHAR_CHECK macro with Rmpfr_inp_str as this *
  * function requires a different condition (!ret vs ret).            */
 
-#define NON_NUMERIC_CHAR_CHECK \
+#define NON_NUMERIC_CHAR_CHECK(inputstr) \
        if(ret) { \
          nnum++; \
          if(SvIV(get_sv("Math::MPFR::NNW", 0))) \
-           warn("string used in %s contains non-numeric characters"
+           warn("string used (%s) in %s contains non-numeric characters", SvPV_nolen(inputstr)
 
 #define BITSEARCH_4 \
           if(tmp & 8) {				\
@@ -405,8 +405,9 @@ typedef _Decimal128 D128;
 #if NVSIZE == 8
 #define MATH_MPFR_MAX_DIG 17
 #define NVSIZE_BITS 53
-#define MATH_MPFR_NV_MAX 1.7976931348623157e+308
-#define MATH_MPFR_NORMAL_MIN 2.2250738585072014e-308
+#define MATH_MPFR_NV_MAX 0x1.fffffffffffffp+1023 /* 32-bit Windows has a problem with evaluating the    *
+                                                  * decimal form of this value if -std=c99 is specified */
+#define MATH_MPFR_NORMAL_MIN 0x1p-1022
 
 # if defined(MPFR_HAVE_BENDIAN)                /* big endian architecture - defined by Makefile.PL */
 
@@ -427,8 +428,8 @@ typedef _Decimal128 D128;
 #elif defined(USE_LONG_DOUBLE)
 #define MATH_MPFR_MAX_DIG 21
 #define NVSIZE_BITS 64
-#define MATH_MPFR_NV_MAX 1.18973149535723176502e4932L
-#define MATH_MPFR_NORMAL_MIN 3.36210314311209350626e-4932L
+#define MATH_MPFR_NV_MAX 0xf.fffffffffffffffp+16380L
+#define MATH_MPFR_NORMAL_MIN 0x8p-16385L
 
 # if defined(MPFR_HAVE_BENDIAN)                /* big endian architecture - defined by Makefile.PL */
 
@@ -455,8 +456,8 @@ typedef _Decimal128 D128;
 #else
 #define MATH_MPFR_MAX_DIG 36
 #define NVSIZE_BITS 113
-#define MATH_MPFR_NV_MAX 1.18973149535723176508575932662800702e+4932Q
-#define MATH_MPFR_NORMAL_MIN 3.3621031431120935062626778173217526e-4932Q
+#define MATH_MPFR_NV_MAX 0x1.ffffffffffffffffffffffffffffp+16383Q
+#define MATH_MPFR_NORMAL_MIN 0x1p-16382Q       /* == 0x8p-16385 */
 
 # if defined(MPFR_HAVE_BENDIAN)                /* big endian architecture - defined by Makefile.PL */
 
